#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
from flashtext import KeywordProcessor
from xml.sax.saxutils import escape, unescape
import argparse

ap = argparse.ArgumentParser()
ap.add_argument('-f', '--cefile', type=str, required=True)
ap.add_argument('-s', '--sep', type=str, default="\t")
ap.add_argument('--titlecolumn', type=int, default=0)
ap.add_argument('--ceflgcolumn', type=int, default=3)
ap.add_argument('--column', type=int, default=4)
ap.add_argument('--case_sensitive', type=bool, default=False)
ap.add_argument('--causeseclabel', type=str, default="c")
ap.add_argument('--effectseclabel', type=str, default="e")
ap.add_argument('--escape', action="store_true")
args = ap.parse_args()

def _escape(string):
    return escape(string, {'"':'&quot;'})

def _unescape(string):
    return unescape(string, {'&quot;':'"'})

def prepare_keyword_processor():
    keyword_processor = KeywordProcessor(case_sensitive=args.case_sensitive)
    with open(args.cefile, 'r') as f:
        for l in f:
            key = l.rstrip("\n").split(args.sep)[0]
            if args.escape:
                key = _escape(key)
            keyword_processor.add_keyword(key)
    return keyword_processor

def main():
    kp = prepare_keyword_processor()
    for l in sys.stdin:
        l = l.rstrip("\n")
        li = l.split(args.sep)
        if len(li) != 5:
            print("Wrong format:%s" % l, file=sys.stderr)
            continue
        title = li[args.titlecolumn]
        ceflg = li[args.ceflgcolumn]
        body = li[args.column]
        found = set()
        for keyword in kp.extract_keywords(body):
            if keyword == title:
                continue
            found.add(keyword)
        if not found:
            continue
        for ce in found:
            if args.escape:
                ce = _unescape(ce)
            li[args.column] = ce
            if ceflg == args.effectseclabel:
                print("%s\t%s\t#\t%s" % (title, ce, args.sep.join(li)))
            elif ceflg == args.causeseclabel:
                print("%s\t%s\t#\t%s" % (ce, title, args.sep.join(li)))

if __name__ == "__main__":
    main()

