#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
from collections import defaultdict
import argparse

ap = argparse.ArgumentParser()
ap.add_argument('-s', '--sep', type=str, default="\t")
args = ap.parse_args()

def sort_pair(wid1, wid2):
    if wid1 <= wid2:
        return (wid1, wid2)
    else:
        return (wid2, wid1)

def readin():
    buf = defaultdict(list)
    count = defaultdict(int)
    for l in sys.stdin:
        l = l.rstrip("\n")
        li = l.split(args.sep)
        wid1, wid2 = li[0], li[1]
        pair = sort_pair(wid1, wid2)
        count[pair] += 1
        buf[pair].append(l)
    return (buf, count)

if __name__ == "__main__":
    (buf, count) = readin()
    for pair, line in buf.items():
        if count[pair] == 1:
            print(args.sep.join(line))
        else:
            print("\t|||\t".join(line), file=sys.stderr)

