#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
import argparse
import traceback

ap = argparse.ArgumentParser()
ap.add_argument('-s', '--sep', type=str, default="\t")
ap.add_argument('--end_of_context', type=str, default=" __EOC__ ")
ap.add_argument('--show_wpairs', action="store_true")
args = ap.parse_args()

pairs = []

l = sys.stdin.readline().rstrip("\n")
li = l.split(args.sep)
try:
    current_lbl, current_pair, current_ctxts = li[0], li[1] + args.sep + li[2], li[5]
except:
    print("Wrong format?:%s EOS" % l, file=sys.stderr)
    traceback.print_exc()
    sys.exit(1)

buf = [current_ctxts]

if args.show_wpairs:
    pairs.append(current_pair)

for l in sys.stdin:
    l = l.rstrip("\n")
    li = l.split(args.sep)
    lbl, pair, ctxts = None, None, None
    try:
        lbl, pair, ctxts = li[0], li[1] + args.sep + li[2], li[5]
    except:
        print("Wrong format?:%s EOS" % l, file=sys.stderr)
        traceback.print_exc()
        sys.exit(1)
    if pair == current_pair:
        if lbl != current_lbl:
            print("Different label for the same pair:%s" % l, file=sys.stderr)
            sys.exit(1)
        buf.append(ctxts)
    else:
        print("%s %s" % (current_lbl, args.end_of_context.join(buf)))
        current_lbl, current_pair, current_ctxts = lbl, pair, ctxts
        buf = [current_ctxts]
        if args.show_wpairs:
            pairs.append(current_pair)

if buf:
    print("%s %s" % (current_lbl, args.end_of_context.join(buf)))

if args.show_wpairs:
    print("\n".join(pairs), file=sys.stderr)

