#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
import wikitextparser as wtp
import xml.etree.ElementTree as ET
import argparse

ap = argparse.ArgumentParser()
ap.add_argument('--pagestart', type=str, default="<page>")
ap.add_argument('--pageend', type=str, default="</page>")
ap.add_argument('--titlepat', type=str, default=".//title")
ap.add_argument('--textpat', type=str, default=".//text")
args = ap.parse_args()

def process(xml):
    root = ET.fromstring(''.join(xml))
    title = root.find(args.titlepat).text.strip()
    text = root.find(args.textpat).text
    if not text:
        return False
    parsed = None
    try:
        parsed = wtp.parse(text)
    except:
        print("Parsing failed for: %s" % title, file=sys.stderr)
        import traceback
        traceback.print_exc()
        return False
    result = set()
    for wl in parsed.wikilinks:
        if title == wl.target:
            continue
        result.add((title, wl.target))
    for e1, e2 in result:
        print("%s\t%s" % (e1, e2))
    return False

def main():
    xml = []
    record_flag = False
    for l in sys.stdin:
        if record_flag:
            xml.append(l)
        if args.pagestart in l:
            record_flag = True
            xml.append(l)
        elif args.pageend in l:
            record_flag = False
            process(xml)
            xml = []

if __name__ == "__main__":
    main()

