#!/usr/bin/env python

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import json
import sys

def concat_claims(claims):
    for rel_id, rel_claims in claims.items():
        for claim in rel_claims:
            yield claim

def to_triplets(ent):
    claims = concat_claims(ent['claims'])
    triplets = []
    e1 = ent['id']
    for claim in claims:
        mainsnak = claim['mainsnak']
        if mainsnak['snaktype'] != "value":
            continue
        if mainsnak['datatype'] == 'wikibase-item':
            rel = mainsnak['property']
            e2 = 'Q{}'.format(mainsnak['datavalue']['value']['numeric-id'])
            triplets.append((e1, rel, e2))
    return triplets

if __name__ == '__main__':
    for line in sys.stdin:
        try:
            ent = json.loads(line.rstrip('\n,'))
            if not ent['id'].startswith('Q'):
                print("Skipping item with id {}".format(ent['id']),
                        file=sys.stderr)
                continue
            print('\n'.join(
                ['{}\t{}\t{}'.format(*t) for t in to_triplets(ent)]),
                    file=sys.stdout)
        except (KeyError, ValueError) as e:
            print(e, file=sys.stderr)

